@@ -8,47 +8,26 @@
 
 mod mock;
 
-use mock::{mock_wallet, TestNodeClient};
+use dusk_jubjub::{JubJubAffine, JubJubScalar};
+use mock::{mock_wallet, TestProverClient};
 
-use dusk_pki::ViewKey;
 use dusk_plonk::prelude::{BlsScalar, Proof};
-use dusk_poseidon::tree::PoseidonBranch;
-use dusk_wallet_core::{
-    NodeClient, Transaction, UnprovenTransaction, POSEIDON_TREE_DEPTH,
-};
-use phoenix_core::Note;
+use dusk_schnorr::Signature;
+use dusk_wallet_core::{ProverClient, UnprovenTransaction};
+use phoenix_core::{Crossover, Fee};
 
 #[derive(Debug)]
-struct SerdeNodeClient {
-    node: TestNodeClient,
+struct SerdeProverClient {
+    prover: TestProverClient,
 }
 
-impl NodeClient for SerdeNodeClient {
+impl ProverClient for SerdeProverClient {
     type Error = ();
 
-    fn fetch_notes(
-        &self,
-        height: u64,
-        vk: &ViewKey,
-    ) -> Result<Vec<Note>, Self::Error> {
-        self.node.fetch_notes(height, vk)
-    }
-
-    fn fetch_anchor(&self) -> Result<BlsScalar, Self::Error> {
-        self.node.fetch_anchor()
-    }
-
-    fn fetch_opening(
-        &self,
-        note: &Note,
-    ) -> Result<PoseidonBranch<POSEIDON_TREE_DEPTH>, Self::Error> {
-        self.node.fetch_opening(note)
-    }
-
-    fn request_proof(
+    fn compute_proof_and_propagate(
         &self,
         utx: &UnprovenTransaction,
-    ) -> Result<Proof, Self::Error> {
+    ) -> Result<(), Self::Error> {
         let utx_bytes = utx.to_bytes().expect("Successful serialization");
         let utx_clone = UnprovenTransaction::from_slice(&utx_bytes)
             .expect("Successful deserialization");
@@ -76,7 +55,30 @@ impl NodeClient for SerdeNodeClient {
         assert_eq!(utx.crossover(), utx_clone.crossover());
         assert_eq!(utx.call(), utx_clone.call());
 
-        self.node.request_proof(utx)
+        self.prover.compute_proof_and_propagate(utx)
+    }
+
+    fn request_stct_proof(
+        &self,
+        fee: &Fee,
+        crossover: &Crossover,
+        value: u64,
+        blinder: JubJubScalar,
+        address: BlsScalar,
+        signature: Signature,
+    ) -> Result<Proof, Self::Error> {
+        self.prover.request_stct_proof(
+            fee, crossover, value, blinder, address, signature,
+        )
+    }
+
+    fn request_wfct_proof(
+        &self,
+        commitment: JubJubAffine,
+        value: u64,
+        blinder: JubJubScalar,
+    ) -> Result<Proof, Self::Error> {
+        self.prover.request_wfct_proof(commitment, value, blinder)
     }
 }
 
@@ -90,34 +92,13 @@ fn serde() {
     let recv_psk = wallet.public_spend_key(1).unwrap();
 
     let ref_id = BlsScalar::random(&mut rng);
-    let tx = wallet
-        .create_transfer_tx(
-            &mut rng, 0, &send_psk, &recv_psk, 100, 100, 1, ref_id,
-        )
+    wallet
+        .transfer(&mut rng, 0, &send_psk, &recv_psk, 100, 100, 1, ref_id)
         .expect("Transaction creation to be successful");
-
-    let tx_bytes = tx.to_bytes().expect("Successful serialization");
-    let tx_clone =
-        Transaction::from_slice(&tx_bytes).expect("Successful deserialization");
-
-    for (null, cnull) in tx.inputs().iter().zip(tx_clone.inputs().iter()) {
-        assert_eq!(null, cnull);
-    }
-
-    for (output, coutput) in tx.outputs().iter().zip(tx_clone.outputs().iter())
-    {
-        assert_eq!(output, coutput);
-    }
-
-    assert_eq!(tx.anchor(), tx_clone.anchor());
-    assert_eq!(tx.proof(), tx_clone.proof());
-    assert_eq!(tx.fee(), tx_clone.fee());
-    assert_eq!(tx.crossover(), tx_clone.crossover());
-    assert_eq!(tx.call(), tx_clone.call());
 }
 
 #[test]
-fn create_transfer_tx() {
+fn transfer() {
     let mut rng = rand::thread_rng();
 
     let wallet = mock_wallet(&mut rng, &[2500, 2500, 5000]);
@@ -126,13 +107,9 @@ fn create_transfer_tx() {
     let recv_psk = wallet.public_spend_key(1).unwrap();
 
     let ref_id = BlsScalar::random(&mut rng);
-    let tx = wallet
-        .create_transfer_tx(
-            &mut rng, 0, &send_psk, &recv_psk, 100, 100, 1, ref_id,
-        )
+    wallet
+        .transfer(&mut rng, 0, &send_psk, &recv_psk, 100, 100, 1, ref_id)
         .expect("Transaction creation to be successful");
-
-    assert_eq!(tx.inputs().len(), 1);
 }
 
 #[test]
